pub struct CacheError(pub String);Expand description
Represents an error encountered when accessing or manipulating the DEK cache.
This error type is used when operations on the DEK cache fail, such as:
- Cache insertion failures
- Cache retrieval errors
- Cache invalidation issues
- Storage capacity problems
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for CacheError
impl Debug for CacheError
Sourceimpl Display for CacheError
impl Display for CacheError
impl Eq for CacheError
Sourceimpl PartialEq for CacheError
impl PartialEq for CacheError
Sourcefn eq(&self, other: &CacheError) -> bool
fn eq(&self, other: &CacheError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CacheError