pub struct GenerateKeyError(pub String);Expand description
Represents an error that can occur during DEK generation.
This error type is used when key generation operations fail, such as:
- Insufficient entropy
- Invalid key parameters
- Algorithm-specific failures
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for GenerateKeyError
impl Debug for GenerateKeyError
Sourceimpl Display for GenerateKeyError
impl Display for GenerateKeyError
impl Eq for GenerateKeyError
Sourceimpl PartialEq for GenerateKeyError
impl PartialEq for GenerateKeyError
Sourcefn eq(&self, other: &GenerateKeyError) -> bool
fn eq(&self, other: &GenerateKeyError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GenerateKeyError