pub struct GeneralError(pub String);Expand description
Represents a more general error in the DEK library.
This error type is used for operational errors that don’t fit into more specific categories, such as:
- Configuration errors
- System-level issues
- Unexpected conditions
Tuple Fields
0: StringTrait Implementations
Sourceimpl Debug for GeneralError
impl Debug for GeneralError
Sourceimpl Display for GeneralError
impl Display for GeneralError
impl Eq for GeneralError
Sourceimpl PartialEq for GeneralError
impl PartialEq for GeneralError
Sourcefn eq(&self, other: &GeneralError) -> bool
fn eq(&self, other: &GeneralError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for GeneralError